Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/blenkernel/intern')
-rw-r--r--source/blender/blenkernel/intern/mask_evaluate.c66
-rw-r--r--source/blender/blenkernel/intern/mask_rasterize.c4
2 files changed, 35 insertions, 35 deletions
diff --git a/source/blender/blenkernel/intern/mask_rasterize.c b/source/blender/blenkernel/intern/mask_rasterize.c
index a43bf41058c..38301d51cbd 100644
--- a/source/blender/blenkernel/intern/mask_rasterize.c
+++ b/source/blender/blenkernel/intern/mask_rasterize.c
@@ -626,11 +626,11 @@ void BKE_maskrasterize_handle_init(MaskRasterHandle *mr_handle, struct Mask *mas
const unsigned int resol_b = BKE_mask_spline_feather_resolution(spline, width, height) / 4;
const unsigned int resol = CLAMPIS(MAX2(resol_a, resol_b), 4, 512);
- diff_points = BKE_mask_spline_differentiate_with_resolution_ex(
+ diff_points = BKE_mask_spline_differentiate_with_resolution(
spline, &tot_diff_point, resol);
if (do_feather) {
- diff_feather_points = BKE_mask_spline_feather_differentiated_points_with_resolution_ex(
+ diff_feather_points = BKE_mask_spline_feather_differentiated_points_with_resolution(
spline, &tot_diff_feather_points, resol, FALSE);
BLI_assert(diff_feather_points);
}
diff --git a/source/blender/blenkernel/intern/mask_evaluate.c b/source/blender/blenkernel/intern/mask_evaluate.c
index 2a4ba5aa3af..f63d027d9f4 100644
--- a/source/blender/blenkernel/intern/mask_evaluate.c
+++ b/source/blender/blenkernel/intern/mask_evaluate.c
@@ -154,10 +154,10 @@ int BKE_mask_spline_differentiate_calc_total(const MaskSpline *spline, const uns
}
}
-float (*BKE_mask_spline_differentiate_with_resolution_ex(MaskSpline *spline,
- unsigned int *tot_diff_point,
- const unsigned int resol
- ))[2]
+float (*BKE_mask_spline_differentiate_with_resolution(MaskSpline *spline,
+ unsigned int *tot_diff_point,
+ const unsigned int resol
+ ))[2]
{
MaskSplinePoint *points_array = BKE_mask_spline_point_array(spline);
@@ -213,13 +213,13 @@ float (*BKE_mask_spline_differentiate_with_resolution_ex(MaskSpline *spline,
return diff_points;
}
-float (*BKE_mask_spline_differentiate_with_resolution(MaskSpline *spline, int width, int height,
- unsigned int *tot_diff_point
- ))[2]
+float (*BKE_mask_spline_differentiate(MaskSpline *spline, int width, int height,
+ unsigned int *tot_diff_point
+ ))[2]
{
int unsigned resol = BKE_mask_spline_resolution(spline, width, height);
- return BKE_mask_spline_differentiate_with_resolution_ex(spline, tot_diff_point, resol);
+ return BKE_mask_spline_differentiate_with_resolution(spline, tot_diff_point, resol);
}
/* ** feather points self-intersection collapse routine ** */
@@ -501,12 +501,12 @@ void BKE_mask_spline_feather_collapse_inner_loops(MaskSpline *spline, float (*fe
#undef BUCKET_INDEX
}
-/** only called from #BKE_mask_spline_feather_differentiated_points_with_resolution_ex() ! */
-static float (*mask_spline_feather_differentiated_points_with_resolution_ex__even(MaskSpline *spline,
- unsigned int *tot_feather_point,
- const unsigned int resol,
- const int do_feather_isect
- ))[2]
+/** only called from #BKE_mask_spline_feather_differentiated_points_with_resolution() ! */
+static float (*mask_spline_feather_differentiated_points_with_resolution__even(MaskSpline *spline,
+ unsigned int *tot_feather_point,
+ const unsigned int resol,
+ const int do_feather_isect
+ ))[2]
{
MaskSplinePoint *points_array = BKE_mask_spline_point_array(spline);
MaskSplinePoint *point_curr, *point_prev;
@@ -574,12 +574,12 @@ static float (*mask_spline_feather_differentiated_points_with_resolution_ex__eve
return feather;
}
-/** only called from #BKE_mask_spline_feather_differentiated_points_with_resolution_ex() ! */
-static float (*mask_spline_feather_differentiated_points_with_resolution_ex__double(MaskSpline *spline,
- unsigned int *tot_feather_point,
- const unsigned int resol,
- const int do_feather_isect
- ))[2]
+/** only called from #BKE_mask_spline_feather_differentiated_points_with_resolution() ! */
+static float (*mask_spline_feather_differentiated_points_with_resolution__double(MaskSpline *spline,
+ unsigned int *tot_feather_point,
+ const unsigned int resol,
+ const int do_feather_isect
+ ))[2]
{
MaskSplinePoint *points_array = BKE_mask_spline_point_array(spline);
@@ -709,22 +709,22 @@ static float (*mask_spline_feather_differentiated_points_with_resolution_ex__dou
}
/**
- * values align with #BKE_mask_spline_differentiate_with_resolution_ex
+ * values align with #BKE_mask_spline_differentiate_with_resolution
* when \a resol arguments match.
*/
-float (*BKE_mask_spline_feather_differentiated_points_with_resolution_ex(MaskSpline *spline,
- unsigned int *tot_feather_point,
- const unsigned int resol,
- const int do_feather_isect
- ))[2]
+float (*BKE_mask_spline_feather_differentiated_points_with_resolution(MaskSpline *spline,
+ unsigned int *tot_feather_point,
+ const unsigned int resol,
+ const int do_feather_isect
+ ))[2]
{
switch (spline->offset_mode) {
case MASK_SPLINE_OFFSET_EVEN:
- return mask_spline_feather_differentiated_points_with_resolution_ex__even(spline, tot_feather_point, resol, do_feather_isect);
+ return mask_spline_feather_differentiated_points_with_resolution__even(spline, tot_feather_point, resol, do_feather_isect);
break;
case MASK_SPLINE_OFFSET_SMOOTH:
default:
- return mask_spline_feather_differentiated_points_with_resolution_ex__double(spline, tot_feather_point, resol, do_feather_isect);
+ return mask_spline_feather_differentiated_points_with_resolution__double(spline, tot_feather_point, resol, do_feather_isect);
break;
}
}
@@ -777,9 +777,9 @@ float (*BKE_mask_spline_feather_points(MaskSpline *spline, int *tot_feather_poin
}
/* *** mask point functions which involve evaluation *** */
-float *BKE_mask_point_segment_feather_diff_with_resolution(MaskSpline *spline, MaskSplinePoint *point,
- int width, int height,
- unsigned int *tot_feather_point)
+float *BKE_mask_point_segment_feather_diff(MaskSpline *spline, MaskSplinePoint *point,
+ int width, int height,
+ unsigned int *tot_feather_point)
{
float *feather, *fp;
unsigned int resol = BKE_mask_spline_feather_resolution(spline, width, height);
@@ -804,8 +804,8 @@ float *BKE_mask_point_segment_feather_diff_with_resolution(MaskSpline *spline, M
return feather;
}
-float *BKE_mask_point_segment_diff_with_resolution(MaskSpline *spline, MaskSplinePoint *point,
- int width, int height, unsigned int *tot_diff_point)
+float *BKE_mask_point_segment_diff(MaskSpline *spline, MaskSplinePoint *point,
+ int width, int height, unsigned int *tot_diff_point)
{
MaskSplinePoint *points_array = BKE_mask_spline_point_array_from_point(spline, point);